#!/bin/bash
# Copyright 2012 Hewlett-Packard Development Company, L.P.
# HP Confidential.  No photocopying.
# Author: Rusty Peng <jian-bo.peng@hp.com>
# Date: 2012/11/15

function action() {
	# echo action \"$1\" \"$2\" \"$3\"

	MSG="$0::$FUNCNAME() bad arg "
	[ $# -ne 3 ] && echo $MSG count && exit 99

	# $2 One of the approved keywords from /etc/init.d/hpshd, it
	#    usually is the $1 passed into this script from there
	[ -z "$2" ] &&  echo $MSG 2 && exit 99
	ACTION=$2

	# $3 Either "silent" or explicit empty string.  There are 4 args here
	[ -n "$3" -a "$3" != "silent" ] && echo "$MSG 3 ($3)" && exit 99
	SILENT=
	[ -n "$3" ] && SILENT=">/dev/null 2>&1"

	RETVAL=0
	cd $HPETC
	if [ -x $1 ]; then
	eval "$1 $ACTION $SILENT"
	R=$?
	[ $R -gt 0 ] && RETVAL=$R
	fi
	return $RETVAL
}


RETHELPER=0
case "$1" in

	# These cases support deployment and are typically only called by 
	# a packager (ie, the scriptlets in RPM-based distributions)

	postinstall)
		# On SuSE, chkconfig prints out status--get rid of that.
                # Avoiding Service network is missed in the runlevels 4 to use service HP message
		# chkconfig --add $PRODNAME >/dev/null
		chkconfig --level 35 $PRODNAME on >/dev/null
		;;

	silentstart)
		action "$SCRIPT" start silent 
		RETHELPER=$?
		;;

	silentstop)
		action "$SCRIPT" stop silent 
		RETHELPER=$?
		;;

	preuninstall)
		chkconfig --del $PRODNAME >/dev/null
		;;

	# Cases called both from spec file and /etc/init.d

	start)
		action "$SCRIPT" "$1" ""	# never silent
		RETHELPER=$?
		;;

	status)
		action "$SCRIPT" "$1" ""	# never silent
		RETHELPER=$?
		;;

	stop)
		action "$SCRIPT" "$1" ""	# never silent
		RETHELPER=$?
		;;

	*)
		echo "Unknown command \"$1\""
		RETHELPER=99
		;;
esac

exit $RETHELPER
